summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--generic/tclBasic.c6
-rw-r--r--generic/tclExecute.c8
2 files changed, 7 insertions, 7 deletions
diff --git a/generic/tclBasic.c b/generic/tclBasic.c
index 7b08f66..7a9b32f 100644
--- a/generic/tclBasic.c
+++ b/generic/tclBasic.c
@@ -16,7 +16,7 @@
* See the file "license.terms" for information on usage and redistribution of
* this file, and for a DISCLAIMER OF ALL WARRANTIES.
*
- * RCS: @(#) $Id: tclBasic.c,v 1.319 2008/07/21 16:26:01 msofer Exp $
+ * RCS: @(#) $Id: tclBasic.c,v 1.320 2008/07/21 19:41:42 msofer Exp $
*/
#include "tclInt.h"
@@ -5059,7 +5059,7 @@ TclEvalEx(
eeFramePtr->line = lines;
iPtr->cmdFramePtr = eeFramePtr;
- code = Tcl_EvalObjv(interp, objectsUsed, objv, TCL_EVAL_NOERR);
+ code = TclEvalObjv(interp, objectsUsed, objv, TCL_EVAL_NOERR, NULL);
iPtr->cmdFramePtr = iPtr->cmdFramePtr->nextPtr;
eeFramePtr->line = NULL;
@@ -7453,7 +7453,7 @@ NRPostProcess(
int objc;
Tcl_ListObjGetElements(NULL, objPtr, &objc, &objv);
- result = Tcl_EvalObjv(interp, objc, objv, flags);
+ result = TclEvalObjv(interp, objc, objv, flags, NULL);
break;
}
case TCL_NR_SCRIPT_TYPE: {
diff --git a/generic/tclExecute.c b/generic/tclExecute.c
index 0be6655..148b3e9 100644
--- a/generic/tclExecute.c
+++ b/generic/tclExecute.c
@@ -14,7 +14,7 @@
* See the file "license.terms" for information on usage and redistribution of
* this file, and for a DISCLAIMER OF ALL WARRANTIES.
*
- * RCS: @(#) $Id: tclExecute.c,v 1.384 2008/07/21 16:26:02 msofer Exp $
+ * RCS: @(#) $Id: tclExecute.c,v 1.385 2008/07/21 19:41:42 msofer Exp $
*/
#include "tclInt.h"
@@ -2686,7 +2686,7 @@ TclExecuteByteCode(
#endif /*TCL_COMPILE_DEBUG*/
/*
* Finally, let Tcl_EvalObjv handle the command.
*
* TIP #280: Record the last piece of info needed by
* 'TclGetSrcInfoForPc', and push the frame.
@@ -2697,7 +2697,7 @@ TclExecuteByteCode(
/*
* Reset the instructionCount variable, since we're about to check
* for async stuff anyway while processing Tcl_EvalObjv
*/
instructionCount = 1;
@@ -2708,7 +2708,7 @@ TclExecuteByteCode(
TEBC_CALL(iPtr) = 1;
recordPtr = TOP_RECORD(iPtr);
#endif
- result = Tcl_EvalObjv(interp, objc, objv, evalFlags);
+ result = TclEvalObjv(interp, objc, objv, evalFlags, NULL);
CACHE_STACK_INFO();
#if (USE_NR_TEBC)
evalFlags = TCL_EVAL_NOERR;
@@ -2686,7 +2686,7 @@ TclExecuteByteCode(
#endif /*TCL_COMPILE_DEBUG*/
/*
- * Finally, let Tcl_EvalObjv handle the command.
+ * Finally, let TclEvalObjv handle the command.
*
* TIP #280: Record the last piece of info needed by
@@ -2697,7 +2697,7 @@ TclExecuteByteCode(
/*
* Reset the instructionCount variable, since we're about to check
- * for async stuff anyway while processing Tcl_EvalObjv
+ * for async stuff anyway while processing TclEvalObjv
*/
instructionCount = 1;